==> models_weebi-1.1.2.tar.gz: lib/src/models/ticket/logic/payment_type.dart <==
// live with typo mistake
class PaymentType {
  final String _paymentType;
  const PaymentType._(this._paymentType);

  @override
  String toString() => _paymentType;

  static const PaymentType cash = PaymentType._('cash');
  static const PaymentType mobileMoney = PaymentType._('mobileMoney');
  static const PaymentType nope = PaymentType._('nope');
  static const PaymentType goods = PaymentType._('goods');
  static const PaymentType cheque = PaymentType._('cheque');
  static const PaymentType cb = PaymentType._('cb');
  static const PaymentType unknown = PaymentType._('');

  static List<PaymentType> allPaiementTypes = [
    cash,
    nope,
    mobileMoney,
    // cheque, // * not visible yet because you still need to have it cash at the bank
    // it is hybrid which annoys me until someone requests it do without
    // cb, // * not visible yet 'cause like mobilemoney
  ];

  static PaymentType tryParse(String val) {
    switch (val) {
      case 'cash':
        return PaymentType.cash;
      case 'mobileMoney':
        return PaymentType.mobileMoney;
      case 'goods':
        return PaymentType.goods;
      case 'cheque':
        return PaymentType.cheque;
      case 'cb':
        return PaymentType.cb;
      case 'nope':
        return PaymentType.nope;
      case '':
        return PaymentType.unknown;
      default:
        print('$val is not a valid paymentType');
        return PaymentType.unknown;
    }
  }

  String get paiementString {
    if (_paymentType == PaymentType.nope.toString()) {
      return 'À crédit';
    } else if (_paymentType == PaymentType.mobileMoney.toString()) {
      return 'Mobile Money';
    } else if (_paymentType == PaymentType.cheque.toString()) {
      return 'Chèque';
    } else if (_paymentType == PaymentType.goods.toString()) {
      return 'Biens';
    } else if (_paymentType == PaymentType.cash.toString()) {
      return 'Cash';
    } else if (_paymentType == PaymentType.cb.toString()) {
      return 'Carte Bancaire';
    } else {
      return 'Inconnu';
    }
  }
}

==> models_weebi-1.1.4.tar.gz: lib/src/models/ticket/logic/payment_type.dart <==
// live with typo mistake
class PaymentType {
  final String _paymentType;
  const PaymentType._(this._paymentType);

  @override
  String toString() => _paymentType;

  static const PaymentType cash = PaymentType._('cash');
  static const PaymentType mobileMoney = PaymentType._('mobileMoney');
  static const PaymentType nope = PaymentType._('nope');
  static const PaymentType goods = PaymentType._('goods');
  static const PaymentType cheque = PaymentType._('cheque');
  static const PaymentType cb = PaymentType._('cb');
  static const PaymentType unknown = PaymentType._('');

  static List<PaymentType> allPaiementTypes = [
    cash,
    nope,
    mobileMoney,
    // cheque, // * not visible yet because you still need to have it cash at the bank
    // it is hybrid which annoys me until someone requests it do without
    // cb, // * not visible yet 'cause like mobilemoney
  ];

  static PaymentType tryParse(String? val) {
    switch (val) {
      case 'cash':
        return PaymentType.cash;
      case 'mobileMoney':
        return PaymentType.mobileMoney;
      case 'goods':
        return PaymentType.goods;
      case 'cheque':
        return PaymentType.cheque;
      case 'cb':
        return PaymentType.cb;
      case 'nope':
        return PaymentType.nope;
      case '':
        return PaymentType.unknown;
      default:
        print('$val is not a valid paymentType');
        return PaymentType.unknown;
    }
  }

  String get paiementString {
    if (_paymentType == PaymentType.nope.toString()) {
      return 'À crédit';
    } else if (_paymentType == PaymentType.mobileMoney.toString()) {
      return 'Mobile Money';
    } else if (_paymentType == PaymentType.cheque.toString()) {
      return 'Chèque';
    } else if (_paymentType == PaymentType.goods.toString()) {
      return 'Biens';
    } else if (_paymentType == PaymentType.cash.toString()) {
      return 'Cash';
    } else if (_paymentType == PaymentType.cb.toString()) {
      return 'Carte Bancaire';
    } else {
      return 'Inconnu';
    }
  }
}
